var namespacelibcamera =
[
    [ "ipa", "namespacelibcamera_1_1ipa.html", "namespacelibcamera_1_1ipa" ],
    [ "controls", "namespacelibcamera_1_1controls.html", "namespacelibcamera_1_1controls" ],
    [ "properties", "namespacelibcamera_1_1properties.html", "namespacelibcamera_1_1properties" ],
    [ "Backtrace", "classlibcamera_1_1Backtrace.html", "classlibcamera_1_1Backtrace" ],
    [ "Extensible", "classlibcamera_1_1Extensible.html", "classlibcamera_1_1Extensible" ],
    [ "EventDispatcher", "classlibcamera_1_1EventDispatcher.html", "classlibcamera_1_1EventDispatcher" ],
    [ "EventDispatcherPoll", "classlibcamera_1_1EventDispatcherPoll.html", "classlibcamera_1_1EventDispatcherPoll" ],
    [ "EventNotifier", "classlibcamera_1_1EventNotifier.html", "classlibcamera_1_1EventNotifier" ],
    [ "File", "classlibcamera_1_1File.html", "classlibcamera_1_1File" ],
    [ "Flags", "classlibcamera_1_1Flags.html", "classlibcamera_1_1Flags" ],
    [ "LogCategory", "classlibcamera_1_1LogCategory.html", "classlibcamera_1_1LogCategory" ],
    [ "LogMessage", "classlibcamera_1_1LogMessage.html", "classlibcamera_1_1LogMessage" ],
    [ "Loggable", "classlibcamera_1_1Loggable.html", "classlibcamera_1_1Loggable" ],
    [ "MemFd", "classlibcamera_1_1MemFd.html", "classlibcamera_1_1MemFd" ],
    [ "Message", "classlibcamera_1_1Message.html", "classlibcamera_1_1Message" ],
    [ "InvokeMessage", "classlibcamera_1_1InvokeMessage.html", "classlibcamera_1_1InvokeMessage" ],
    [ "Mutex", "classlibcamera_1_1Mutex.html", null ],
    [ "MutexLocker", "classlibcamera_1_1MutexLocker.html", null ],
    [ "ConditionVariable", "classlibcamera_1_1ConditionVariable.html", null ],
    [ "Signal", "classlibcamera_1_1Signal.html", "classlibcamera_1_1Signal" ],
    [ "Object", "classlibcamera_1_1Object.html", "classlibcamera_1_1Object" ],
    [ "Semaphore", "classlibcamera_1_1Semaphore.html", "classlibcamera_1_1Semaphore" ],
    [ "SharedFD", "classlibcamera_1_1SharedFD.html", "classlibcamera_1_1SharedFD" ],
    [ "Thread", "classlibcamera_1_1Thread.html", "classlibcamera_1_1Thread" ],
    [ "Timer", "classlibcamera_1_1Timer.html", "classlibcamera_1_1Timer" ],
    [ "UniqueFD", "classlibcamera_1_1UniqueFD.html", "classlibcamera_1_1UniqueFD" ],
    [ "SensorConfiguration", "classlibcamera_1_1SensorConfiguration.html", "classlibcamera_1_1SensorConfiguration" ],
    [ "CameraConfiguration", "classlibcamera_1_1CameraConfiguration.html", "classlibcamera_1_1CameraConfiguration" ],
    [ "Camera", "classlibcamera_1_1Camera.html", "classlibcamera_1_1Camera" ],
    [ "CameraManager", "classlibcamera_1_1CameraManager.html", "classlibcamera_1_1CameraManager" ],
    [ "ColorSpace", "classlibcamera_1_1ColorSpace.html", "classlibcamera_1_1ColorSpace" ],
    [ "ControlValue", "classlibcamera_1_1ControlValue.html", "classlibcamera_1_1ControlValue" ],
    [ "ControlId", "classlibcamera_1_1ControlId.html", "classlibcamera_1_1ControlId" ],
    [ "Control", "classlibcamera_1_1Control.html", "classlibcamera_1_1Control" ],
    [ "ControlInfo", "classlibcamera_1_1ControlInfo.html", "classlibcamera_1_1ControlInfo" ],
    [ "ControlInfoMap", "classlibcamera_1_1ControlInfoMap.html", "classlibcamera_1_1ControlInfoMap" ],
    [ "ControlList", "classlibcamera_1_1ControlList.html", "classlibcamera_1_1ControlList" ],
    [ "Fence", "classlibcamera_1_1Fence.html", "classlibcamera_1_1Fence" ],
    [ "FrameMetadata", "structlibcamera_1_1FrameMetadata.html", "structlibcamera_1_1FrameMetadata" ],
    [ "FrameBuffer", "classlibcamera_1_1FrameBuffer.html", "classlibcamera_1_1FrameBuffer" ],
    [ "FrameBufferAllocator", "classlibcamera_1_1FrameBufferAllocator.html", "classlibcamera_1_1FrameBufferAllocator" ],
    [ "Point", "classlibcamera_1_1Point.html", "classlibcamera_1_1Point" ],
    [ "Size", "classlibcamera_1_1Size.html", "classlibcamera_1_1Size" ],
    [ "SizeRange", "classlibcamera_1_1SizeRange.html", "classlibcamera_1_1SizeRange" ],
    [ "Rectangle", "classlibcamera_1_1Rectangle.html", "classlibcamera_1_1Rectangle" ],
    [ "BayerFormat", "classlibcamera_1_1BayerFormat.html", "classlibcamera_1_1BayerFormat" ],
    [ "ByteStreamBuffer", "classlibcamera_1_1ByteStreamBuffer.html", "classlibcamera_1_1ByteStreamBuffer" ],
    [ "CameraControlValidator", "classlibcamera_1_1CameraControlValidator.html", "classlibcamera_1_1CameraControlValidator" ],
    [ "CameraLens", "classlibcamera_1_1CameraLens.html", "classlibcamera_1_1CameraLens" ],
    [ "CameraSensor", "classlibcamera_1_1CameraSensor.html", "classlibcamera_1_1CameraSensor" ],
    [ "CameraSensorFactoryBase", "classlibcamera_1_1CameraSensorFactoryBase.html", "classlibcamera_1_1CameraSensorFactoryBase" ],
    [ "CameraSensorFactory", "classlibcamera_1_1CameraSensorFactory.html", "classlibcamera_1_1CameraSensorFactory" ],
    [ "CameraSensorProperties", "structlibcamera_1_1CameraSensorProperties.html", "structlibcamera_1_1CameraSensorProperties" ],
    [ "ClockRecovery", "classlibcamera_1_1ClockRecovery.html", "classlibcamera_1_1ClockRecovery" ],
    [ "ControlSerializer", "classlibcamera_1_1ControlSerializer.html", "classlibcamera_1_1ControlSerializer" ],
    [ "ControlValidator", "classlibcamera_1_1ControlValidator.html", "classlibcamera_1_1ControlValidator" ],
    [ "Converter", "classlibcamera_1_1Converter.html", "classlibcamera_1_1Converter" ],
    [ "ConverterFactoryBase", "classlibcamera_1_1ConverterFactoryBase.html", "classlibcamera_1_1ConverterFactoryBase" ],
    [ "ConverterFactory", "classlibcamera_1_1ConverterFactory.html", "classlibcamera_1_1ConverterFactory" ],
    [ "ConverterDW100Module", "classlibcamera_1_1ConverterDW100Module.html", "classlibcamera_1_1ConverterDW100Module" ],
    [ "Dw100VertexMap", "classlibcamera_1_1Dw100VertexMap.html", "classlibcamera_1_1Dw100VertexMap" ],
    [ "V4L2M2MConverter", "classlibcamera_1_1V4L2M2MConverter.html", "classlibcamera_1_1V4L2M2MConverter" ],
    [ "DebugMetadata", "classlibcamera_1_1DebugMetadata.html", "classlibcamera_1_1DebugMetadata" ],
    [ "DelayedControls", "classlibcamera_1_1DelayedControls.html", "classlibcamera_1_1DelayedControls" ],
    [ "DeviceMatch", "classlibcamera_1_1DeviceMatch.html", "classlibcamera_1_1DeviceMatch" ],
    [ "DeviceEnumerator", "classlibcamera_1_1DeviceEnumerator.html", "classlibcamera_1_1DeviceEnumerator" ],
    [ "DmaBufAllocator", "classlibcamera_1_1DmaBufAllocator.html", "classlibcamera_1_1DmaBufAllocator" ],
    [ "DmaSyncer", "classlibcamera_1_1DmaSyncer.html", "classlibcamera_1_1DmaSyncer" ],
    [ "eGLImage", "classlibcamera_1_1eGLImage.html", "classlibcamera_1_1eGLImage" ],
    [ "eGL", "classlibcamera_1_1eGL.html", "classlibcamera_1_1eGL" ],
    [ "PixelFormatInfo", "classlibcamera_1_1PixelFormatInfo.html", "classlibcamera_1_1PixelFormatInfo" ],
    [ "GlobalConfiguration", "classlibcamera_1_1GlobalConfiguration.html", "classlibcamera_1_1GlobalConfiguration" ],
    [ "IPADataSerializer", "classlibcamera_1_1IPADataSerializer.html", null ],
    [ "IPAManager", "classlibcamera_1_1IPAManager.html", "classlibcamera_1_1IPAManager" ],
    [ "IPAModule", "classlibcamera_1_1IPAModule.html", "classlibcamera_1_1IPAModule" ],
    [ "IPAProxy", "classlibcamera_1_1IPAProxy.html", "classlibcamera_1_1IPAProxy" ],
    [ "IPCMessage", "classlibcamera_1_1IPCMessage.html", "classlibcamera_1_1IPCMessage" ],
    [ "IPCPipe", "classlibcamera_1_1IPCPipe.html", "classlibcamera_1_1IPCPipe" ],
    [ "IPCUnixSocket", "classlibcamera_1_1IPCUnixSocket.html", "classlibcamera_1_1IPCUnixSocket" ],
    [ "MappedBuffer", "classlibcamera_1_1MappedBuffer.html", "classlibcamera_1_1MappedBuffer" ],
    [ "MappedFrameBuffer", "classlibcamera_1_1MappedFrameBuffer.html", "classlibcamera_1_1MappedFrameBuffer" ],
    [ "Matrix", "classlibcamera_1_1Matrix.html", "classlibcamera_1_1Matrix" ],
    [ "MediaDevice", "classlibcamera_1_1MediaDevice.html", "classlibcamera_1_1MediaDevice" ],
    [ "MediaObject", "classlibcamera_1_1MediaObject.html", "classlibcamera_1_1MediaObject" ],
    [ "MediaLink", "classlibcamera_1_1MediaLink.html", "classlibcamera_1_1MediaLink" ],
    [ "MediaPad", "classlibcamera_1_1MediaPad.html", "classlibcamera_1_1MediaPad" ],
    [ "MediaEntity", "classlibcamera_1_1MediaEntity.html", "classlibcamera_1_1MediaEntity" ],
    [ "MediaPipeline", "classlibcamera_1_1MediaPipeline.html", "classlibcamera_1_1MediaPipeline" ],
    [ "PipelineHandler", "classlibcamera_1_1PipelineHandler.html", "classlibcamera_1_1PipelineHandler" ],
    [ "PipelineHandlerFactoryBase", "classlibcamera_1_1PipelineHandlerFactoryBase.html", "classlibcamera_1_1PipelineHandlerFactoryBase" ],
    [ "PipelineHandlerFactory", "classlibcamera_1_1PipelineHandlerFactory.html", "classlibcamera_1_1PipelineHandlerFactory" ],
    [ "Process", "classlibcamera_1_1Process.html", "classlibcamera_1_1Process" ],
    [ "PubKey", "classlibcamera_1_1PubKey.html", "classlibcamera_1_1PubKey" ],
    [ "SharedMem", "classlibcamera_1_1SharedMem.html", "classlibcamera_1_1SharedMem" ],
    [ "SharedMemObject", "classlibcamera_1_1SharedMemObject.html", "classlibcamera_1_1SharedMemObject" ],
    [ "Benchmark", "classlibcamera_1_1Benchmark.html", "classlibcamera_1_1Benchmark" ],
    [ "DebayerParams", "structlibcamera_1_1DebayerParams.html", "structlibcamera_1_1DebayerParams" ],
    [ "SoftwareIsp", "classlibcamera_1_1SoftwareIsp.html", "classlibcamera_1_1SoftwareIsp" ],
    [ "SwIspStats", "structlibcamera_1_1SwIspStats.html", "structlibcamera_1_1SwIspStats" ],
    [ "SwStatsCpu", "classlibcamera_1_1SwStatsCpu.html", "classlibcamera_1_1SwStatsCpu" ],
    [ "V4L2Device", "classlibcamera_1_1V4L2Device.html", "classlibcamera_1_1V4L2Device" ],
    [ "V4L2PixelFormat", "classlibcamera_1_1V4L2PixelFormat.html", "classlibcamera_1_1V4L2PixelFormat" ],
    [ "V4L2Request", "classlibcamera_1_1V4L2Request.html", "classlibcamera_1_1V4L2Request" ],
    [ "MediaBusFormatInfo", "classlibcamera_1_1MediaBusFormatInfo.html", "classlibcamera_1_1MediaBusFormatInfo" ],
    [ "V4L2SubdeviceCapability", "structlibcamera_1_1V4L2SubdeviceCapability.html", "structlibcamera_1_1V4L2SubdeviceCapability" ],
    [ "V4L2SubdeviceFormat", "structlibcamera_1_1V4L2SubdeviceFormat.html", "structlibcamera_1_1V4L2SubdeviceFormat" ],
    [ "V4L2Subdevice", "classlibcamera_1_1V4L2Subdevice.html", "classlibcamera_1_1V4L2Subdevice" ],
    [ "V4L2Capability", "structlibcamera_1_1V4L2Capability.html", "structlibcamera_1_1V4L2Capability" ],
    [ "V4L2BufferCache", "classlibcamera_1_1V4L2BufferCache.html", "classlibcamera_1_1V4L2BufferCache" ],
    [ "V4L2DeviceFormat", "classlibcamera_1_1V4L2DeviceFormat.html", "classlibcamera_1_1V4L2DeviceFormat" ],
    [ "V4L2VideoDevice", "classlibcamera_1_1V4L2VideoDevice.html", "classlibcamera_1_1V4L2VideoDevice" ],
    [ "V4L2M2MDevice", "classlibcamera_1_1V4L2M2MDevice.html", "classlibcamera_1_1V4L2M2MDevice" ],
    [ "Vector", "classlibcamera_1_1Vector.html", "classlibcamera_1_1Vector" ],
    [ "YamlObject", "classlibcamera_1_1YamlObject.html", "classlibcamera_1_1YamlObject" ],
    [ "YamlParser", "classlibcamera_1_1YamlParser.html", null ],
    [ "ipa_controls_header", "structlibcamera_1_1ipa__controls__header.html", "structlibcamera_1_1ipa__controls__header" ],
    [ "ipa_control_value_entry", "structlibcamera_1_1ipa__control__value__entry.html", "structlibcamera_1_1ipa__control__value__entry" ],
    [ "ipa_control_list_entry", "structlibcamera_1_1ipa__control__list__entry.html", "structlibcamera_1_1ipa__control__list__entry" ],
    [ "ipa_control_info_entry", "structlibcamera_1_1ipa__control__info__entry.html", "structlibcamera_1_1ipa__control__info__entry" ],
    [ "IPAInterface", "classlibcamera_1_1IPAInterface.html", null ],
    [ "IPAModuleInfo", "structlibcamera_1_1IPAModuleInfo.html", "structlibcamera_1_1IPAModuleInfo" ],
    [ "PixelFormat", "classlibcamera_1_1PixelFormat.html", "classlibcamera_1_1PixelFormat" ],
    [ "Request", "classlibcamera_1_1Request.html", "classlibcamera_1_1Request" ],
    [ "StreamFormats", "classlibcamera_1_1StreamFormats.html", "classlibcamera_1_1StreamFormats" ],
    [ "StreamConfiguration", "structlibcamera_1_1StreamConfiguration.html", "structlibcamera_1_1StreamConfiguration" ],
    [ "Stream", "classlibcamera_1_1Stream.html", "classlibcamera_1_1Stream" ],
    [ "LogOutput", "classlibcamera_1_1LogOutput.html", "classlibcamera_1_1LogOutput" ],
    [ "Logger", "classlibcamera_1_1Logger.html", "classlibcamera_1_1Logger" ],
    [ "MessageQueue", "classlibcamera_1_1MessageQueue.html", "classlibcamera_1_1MessageQueue" ],
    [ "ThreadData", "classlibcamera_1_1ThreadData.html", "classlibcamera_1_1ThreadData" ],
    [ "ThreadMain", "classlibcamera_1_1ThreadMain.html", "classlibcamera_1_1ThreadMain" ],
    [ "Debayer", "classlibcamera_1_1Debayer.html", "classlibcamera_1_1Debayer" ],
    [ "DebayerCpu", "classlibcamera_1_1DebayerCpu.html", "classlibcamera_1_1DebayerCpu" ],
    [ "DebayerEGL", "classlibcamera_1_1DebayerEGL.html", "classlibcamera_1_1DebayerEGL" ],
    [ "IPACameraSensorInfo", "structlibcamera_1_1IPACameraSensorInfo.html", "structlibcamera_1_1IPACameraSensorInfo" ],
    [ "IPABuffer", "structlibcamera_1_1IPABuffer.html", "structlibcamera_1_1IPABuffer" ],
    [ "IPASettings", "structlibcamera_1_1IPASettings.html", "structlibcamera_1_1IPASettings" ],
    [ "IPAStream", "structlibcamera_1_1IPAStream.html", "structlibcamera_1_1IPAStream" ],
    [ "ControlIdMap", "namespacelibcamera.html#aa331d4459b6d32bfcf9c1c6b865a41bf", null ],
    [ "RGB", "namespacelibcamera.html#a9bcbbdc486cdc7466dec559b99c544a0", null ],
    [ "ConnectionType", "namespacelibcamera.html#ae2c8412791b9597d590a7d0b2c9e2919", [
      [ "ConnectionTypeAuto", "namespacelibcamera.html#ae2c8412791b9597d590a7d0b2c9e2919ae8d08355860ab248591945b563fb39f4", null ],
      [ "ConnectionTypeDirect", "namespacelibcamera.html#ae2c8412791b9597d590a7d0b2c9e2919a654040cc9784221ba0c421778f3f675b", null ],
      [ "ConnectionTypeQueued", "namespacelibcamera.html#ae2c8412791b9597d590a7d0b2c9e2919ad27c6f2190ce9ce93160a2c61baa2321", null ],
      [ "ConnectionTypeBlocking", "namespacelibcamera.html#ae2c8412791b9597d590a7d0b2c9e2919a8ef590d2ece4924a6d84456052d36d25", null ]
    ] ],
    [ "ControlType", "namespacelibcamera.html#a40a8adae6eaa668ac965dc350ca2b295", [
      [ "ControlTypeNone", "namespacelibcamera.html#a40a8adae6eaa668ac965dc350ca2b295aede8a0acca1993959123be05d7658632", null ],
      [ "ControlTypeBool", "namespacelibcamera.html#a40a8adae6eaa668ac965dc350ca2b295a3d4c8bedfbb5e51d76994a2e87a67f62", null ],
      [ "ControlTypeByte", "namespacelibcamera.html#a40a8adae6eaa668ac965dc350ca2b295a8f45eb83a57b2b8b288b8d629d1f7d1c", null ],
      [ "ControlTypeUnsigned16", "namespacelibcamera.html#a40a8adae6eaa668ac965dc350ca2b295a09469e4c58b004137bd8d7a173891669", null ],
      [ "ControlTypeUnsigned32", "namespacelibcamera.html#a40a8adae6eaa668ac965dc350ca2b295a70d92e5a993630d9f901680adc1ae445", null ],
      [ "ControlTypeInteger32", "namespacelibcamera.html#a40a8adae6eaa668ac965dc350ca2b295a3b974a2de26501f2552838bade41cd21", null ],
      [ "ControlTypeInteger64", "namespacelibcamera.html#a40a8adae6eaa668ac965dc350ca2b295ad0768733f194f15df0142f215dfa34c1", null ],
      [ "ControlTypeFloat", "namespacelibcamera.html#a40a8adae6eaa668ac965dc350ca2b295a7143430d9540bd156127786e1a904c25", null ],
      [ "ControlTypeString", "namespacelibcamera.html#a40a8adae6eaa668ac965dc350ca2b295a4f4c0476956145cabc1f8356d6dcc4b2", null ]
    ] ],
    [ "ipa_controls_id_map_type", "namespacelibcamera.html#a15081aa9ebc49a6db6aff905354d1366", [
      [ "IPA_CONTROL_ID_MAP_CONTROLS", "namespacelibcamera.html#a15081aa9ebc49a6db6aff905354d1366abc9ae661d39a97ecedfef81c9dc89d65", null ],
      [ "IPA_CONTROL_ID_MAP_PROPERTIES", "namespacelibcamera.html#a15081aa9ebc49a6db6aff905354d1366adddcdd8c640fc3fd241b3b43607bff26", null ],
      [ "IPA_CONTROL_ID_MAP_V4L2", "namespacelibcamera.html#a15081aa9ebc49a6db6aff905354d1366af14f43173a61a0c28644a8c5ebf3ab1a", null ]
    ] ],
    [ "LoggingTarget", "namespacelibcamera.html#ac7785b09b0faadf7fb6e3536795e3d1f", [
      [ "LoggingTargetNone", "namespacelibcamera.html#ac7785b09b0faadf7fb6e3536795e3d1fa81d13cf586269f01b23a475745f71661", null ],
      [ "LoggingTargetSyslog", "namespacelibcamera.html#ac7785b09b0faadf7fb6e3536795e3d1fad51b8e0b84ab5006d142ad4f844a0176", null ],
      [ "LoggingTargetFile", "namespacelibcamera.html#ac7785b09b0faadf7fb6e3536795e3d1fa0cf9c91e701e784e468f02f42b0b30d9", null ],
      [ "LoggingTargetStream", "namespacelibcamera.html#ac7785b09b0faadf7fb6e3536795e3d1fad544d061cb8ed5a9b0e1b8390856cd45", null ]
    ] ],
    [ "LogSeverity", "namespacelibcamera.html#a68f26f5a54a5bb105f2e7422215a0ca3", [
      [ "LogDebug", "namespacelibcamera.html#a68f26f5a54a5bb105f2e7422215a0ca3a1fba79816259824265a453d8c5b5a0cd", null ],
      [ "LogInfo", "namespacelibcamera.html#a68f26f5a54a5bb105f2e7422215a0ca3a2c3ed6a830a2d48c692e7a30e9841da8", null ],
      [ "LogWarning", "namespacelibcamera.html#a68f26f5a54a5bb105f2e7422215a0ca3aae62a40b6af1c1a0f2f93db27c2baadc", null ],
      [ "LogError", "namespacelibcamera.html#a68f26f5a54a5bb105f2e7422215a0ca3aa7c033fb5bf534a0f64261278159ee88", null ],
      [ "LogFatal", "namespacelibcamera.html#a68f26f5a54a5bb105f2e7422215a0ca3ac9e03c4229b7330c7b1ef97f0d868ea6", null ]
    ] ],
    [ "Orientation", "namespacelibcamera.html#a80ea01625b93ecfe879249ac60c79384", [
      [ "Rotate0", "namespacelibcamera.html#a80ea01625b93ecfe879249ac60c79384a291b44223b90e70be1fade1eff8a55e0", null ],
      [ "Rotate0Mirror", "namespacelibcamera.html#a80ea01625b93ecfe879249ac60c79384a8c0ca32ba7e4de48842b5828d1cc4bbb", null ],
      [ "Rotate180", "namespacelibcamera.html#a80ea01625b93ecfe879249ac60c79384a371980c5d153a94cf022d6b4daa4d34c", null ],
      [ "Rotate180Mirror", "namespacelibcamera.html#a80ea01625b93ecfe879249ac60c79384a9299b4523bc8f8a8a3cf874fccc39e56", null ],
      [ "Rotate90Mirror", "namespacelibcamera.html#a80ea01625b93ecfe879249ac60c79384ad3e952bbaf7e50a879f42b7968e07a79", null ],
      [ "Rotate270", "namespacelibcamera.html#a80ea01625b93ecfe879249ac60c79384a59c609399b2fb3956ecac7df34a76c2f", null ],
      [ "Rotate270Mirror", "namespacelibcamera.html#a80ea01625b93ecfe879249ac60c79384a42099bec2daf386b1daeffe0854cab21", null ],
      [ "Rotate90", "namespacelibcamera.html#a80ea01625b93ecfe879249ac60c79384a1d20b3969ea74725dd1a5b7669d60a98", null ]
    ] ],
    [ "StreamRole", "namespacelibcamera.html#a295d1f5e7828d95c0b0aabc0a8baac03", [
      [ "Raw", "namespacelibcamera.html#a295d1f5e7828d95c0b0aabc0a8baac03a65e65c8ab0d8609ce12fc68a03cb8e00", null ],
      [ "StillCapture", "namespacelibcamera.html#a295d1f5e7828d95c0b0aabc0a8baac03ab6d498e09460a56e1c69af18830c9b9a", null ],
      [ "VideoRecording", "namespacelibcamera.html#a295d1f5e7828d95c0b0aabc0a8baac03ae1ff48054403b149f903eb40e16ec86e", null ],
      [ "Viewfinder", "namespacelibcamera.html#a295d1f5e7828d95c0b0aabc0a8baac03a30b5987e4c03f83a7e1909e4f72eefd4", null ]
    ] ],
    [ "Transform", "namespacelibcamera.html#a371b6d17d531b85c035c4e889b116571", [
      [ "Identity", "namespacelibcamera.html#a371b6d17d531b85c035c4e889b116571ac9c5c65fb4af9cf90eb99b3b84424189", null ],
      [ "Rot0", "namespacelibcamera.html#a371b6d17d531b85c035c4e889b116571a4bb6c9559a08829b1fd0a5eedd2eecb5", null ],
      [ "HFlip", "namespacelibcamera.html#a371b6d17d531b85c035c4e889b116571a01725f7032dd7fc3bc68806a46628cdd", null ],
      [ "VFlip", "namespacelibcamera.html#a371b6d17d531b85c035c4e889b116571a0b5d83f7ecb707aee4151b6575ca5af7", null ],
      [ "HVFlip", "namespacelibcamera.html#a371b6d17d531b85c035c4e889b116571ab999446b23b657dfbbce99e636bf9fbc", null ],
      [ "Rot180", "namespacelibcamera.html#a371b6d17d531b85c035c4e889b116571af35f5bfafcf9cdad2100127dfc0109fd", null ],
      [ "Transpose", "namespacelibcamera.html#a371b6d17d531b85c035c4e889b116571aaf70b1ac863830a4e1ce6268c8399f54", null ],
      [ "Rot270", "namespacelibcamera.html#a371b6d17d531b85c035c4e889b116571abd039fd6afddf90dab22307d3a18d11a", null ],
      [ "Rot90", "namespacelibcamera.html#a371b6d17d531b85c035c4e889b116571ad5251a97af7b4036b4528a54405ea2ad", null ],
      [ "Rot180Transpose", "namespacelibcamera.html#a371b6d17d531b85c035c4e889b116571adaa7494d424939ff93c1c9396b065732", null ]
    ] ],
    [ "_log", "namespacelibcamera.html#a4d4c3ef21c98fab4eb53d7bcc4779e24", null ],
    [ "ipaCreate", "namespacelibcamera.html#af40a632a4025a789df881469fe54e681", null ],
    [ "logSetFile", "namespacelibcamera.html#a4fb1124bbbee917f5a29dbe79930f884", null ],
    [ "logSetLevel", "namespacelibcamera.html#a1818bc26a0478a661f39f0a54f4894a4", null ],
    [ "logSetStream", "namespacelibcamera.html#a0e15016b52a1d9cf09e21517bf67cb4a", null ],
    [ "logSetTarget", "namespacelibcamera.html#ab2fe53d88af8815d6e22008802bd195d", null ],
    [ "operator!", "namespacelibcamera.html#aab7c0788509ace93133168772907fb21", null ],
    [ "operator!=", "namespacelibcamera.html#aaa48008ef5f18f39354e32074ef8a63f", null ],
    [ "operator&", "namespacelibcamera.html#ab4c2f17a92c7c0cf81cab4b4b394d898", null ],
    [ "operator&=", "namespacelibcamera.html#a33307ddc15300100702598b127828e07", null ],
    [ "operator*", "namespacelibcamera.html#ae777ae9fc82d528842fbe9e6cfb143d2", null ],
    [ "operator*", "namespacelibcamera.html#ab6040cd1d6bb2fffe45dbbf1b8470cbc", null ],
    [ "operator*", "namespacelibcamera.html#ac077ddd7639033ada89a6b9af54cf109", null ],
    [ "operator*", "namespacelibcamera.html#aa3714da6d73d2c21990f5900cbabe37d", null ],
    [ "operator*", "namespacelibcamera.html#a67ccaafd34c635aa736d061542f9f87c", null ],
    [ "operator*", "namespacelibcamera.html#a582c114db169ee1cbbd4a7bc42661f09", null ],
    [ "operator+", "namespacelibcamera.html#aa03b99517d057cab8771c4f022b18e18", null ],
    [ "operator-", "namespacelibcamera.html#ae470c767d80e939243374f4fa4cd29fd", null ],
    [ "operator/", "namespacelibcamera.html#ad729db99741d9b04e5ad6a58bb493a2c", null ],
    [ "operator<", "namespacelibcamera.html#aae5e9f4598b9b08891fb948be27a5bd7", null ],
    [ "operator<<", "namespacelibcamera.html#a6db34d536d64107cde86d07be139c679", null ],
    [ "operator<<", "namespacelibcamera.html#ad08fea79710eb203636df7d0121fe593", null ],
    [ "operator<<", "namespacelibcamera.html#a9728762c17a26822b991fe3177d908e8", null ],
    [ "operator<<", "namespacelibcamera.html#a4f4f4cf5cb99b8fb1baf2ff47d0e9d7e", null ],
    [ "operator<<", "namespacelibcamera.html#a6a6e77c9dfce545e42160e947aed5471", null ],
    [ "operator<<", "namespacelibcamera.html#a3c43218b071c91c93d86cbb665fa4baa", null ],
    [ "operator<<", "namespacelibcamera.html#ad90cf3d2c67100c961e8028d1ccc1753", null ],
    [ "operator<<", "namespacelibcamera.html#a832d9ee4aff95db6ce004768b22fcc87", null ],
    [ "operator<<", "namespacelibcamera.html#a35e27c344807e47fdf1416f1a1573f83", null ],
    [ "operator<<", "namespacelibcamera.html#a5af0e8921c435c654901a8adea02b66c", null ],
    [ "operator<<", "namespacelibcamera.html#aadde8916b8c86c682c5ea0b6d205538e", null ],
    [ "operator<<", "namespacelibcamera.html#a861d7a8cce3bde75c10c054a65d5f657", null ],
    [ "operator<<", "namespacelibcamera.html#afbf98fad8e8d076c7edcec7b13274e82", null ],
    [ "operator<<", "namespacelibcamera.html#ad2e8e4ac23355fd209003593f0da326f", null ],
    [ "operator<<", "namespacelibcamera.html#acea9b847615fec15821902faaac967b7", null ],
    [ "operator<<", "namespacelibcamera.html#a9836c4c462b71b192a43b368b1555571", null ],
    [ "operator<<", "namespacelibcamera.html#aaf340cf77934640c22a77e312be00e0b", null ],
    [ "operator<<", "namespacelibcamera.html#aa4befed8e0befd567ed2f8bdeaf19f82", null ],
    [ "operator==", "namespacelibcamera.html#aac4e0b5c62c884f39de82939b8a42549", null ],
    [ "operator==", "namespacelibcamera.html#a9a4ec66aa71938514d43ab027fe308db", null ],
    [ "operator==", "namespacelibcamera.html#abc8567725b5bf15396ea4e87faa08a8f", null ],
    [ "operator==", "namespacelibcamera.html#aefa56d56355694c6ba1e32a5e9c81f59", null ],
    [ "operator==", "namespacelibcamera.html#ac999efe2c1913ea8cdcfefa4f9ded359", null ],
    [ "operator==", "namespacelibcamera.html#a0423b1d8e6dc206e717030a9d1fa71cf", null ],
    [ "operator==", "namespacelibcamera.html#abf523068ee1f081bee8d1dd906c7d128", null ],
    [ "operator==", "namespacelibcamera.html#aced6783564bda1a14f40cb72fe9edc74", null ],
    [ "operator^", "namespacelibcamera.html#a906d269e702bba58517f6aced239af10", null ],
    [ "operator^=", "namespacelibcamera.html#ae9daa244428448fb0537370cb0bb2449", null ],
    [ "operator|", "namespacelibcamera.html#a7a895199ceb604882ac29ef46fd97171", null ],
    [ "operator|=", "namespacelibcamera.html#ad7aacd4c6465bf43da28ca439d2f7c27", null ],
    [ "operator~", "namespacelibcamera.html#a538b685bf5ad8e9103ccac21cc92ed7c", null ],
    [ "orientationFromRotation", "namespacelibcamera.html#aa8cfd315901c648f69b6a87555f3c056", null ],
    [ "transformFromRotation", "namespacelibcamera.html#a3c5f3e974000ca0d041bf8e4603f4959", null ],
    [ "transformToString", "namespacelibcamera.html#a9c8a5f0360baaaea3075a28bd59a16e3", null ],
    [ "ipaModuleInfo", "namespacelibcamera.html#adb3486858c75e0c85ae2532d72fb784b", null ]
];